<?php

namespace Litecms\Catporfolio\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Catporfolio\Models\Catporfolio;

class CatporfolioPolicy
{

    /**
     * Determine if the given user can view the catporfolio.
     *
     * @param UserPolicy $user
     * @param Catporfolio $catporfolio
     *
     * @return bool
     */
    public function view(UserPolicy $user, Catporfolio $catporfolio)
    {
        if ($user->canDo('catporfolio.catporfolio.view') && $user->isAdmin()) {
            return true;
        }

        return $catporfolio->user_id == user_id() && $catporfolio->user_type == user_type();
    }

    /**
     * Determine if the given user can create a catporfolio.
     *
     * @param UserPolicy $user
     * @param Catporfolio $catporfolio
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('catporfolio.catporfolio.create');
    }

    /**
     * Determine if the given user can update the given catporfolio.
     *
     * @param UserPolicy $user
     * @param Catporfolio $catporfolio
     *
     * @return bool
     */
    public function update(UserPolicy $user, Catporfolio $catporfolio)
    {
        if ($user->canDo('catporfolio.catporfolio.edit') && $user->isAdmin()) {
            return true;
        }

        return $catporfolio->user_id == user_id() && $catporfolio->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given catporfolio.
     *
     * @param UserPolicy $user
     * @param Catporfolio $catporfolio
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Catporfolio $catporfolio)
    {
        return $catporfolio->user_id == user_id() && $catporfolio->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given catporfolio.
     *
     * @param UserPolicy $user
     * @param Catporfolio $catporfolio
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Catporfolio $catporfolio)
    {
        if ($user->canDo('catporfolio.catporfolio.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given catporfolio.
     *
     * @param UserPolicy $user
     * @param Catporfolio $catporfolio
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Catporfolio $catporfolio)
    {
        if ($user->canDo('catporfolio.catporfolio.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
