<?php

namespace Litecms\Catporfolio\Providers;

use Illuminate\Support\ServiceProvider;

class CatporfolioServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'catporfolio');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'catporfolio');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.catporfolio', function ($app) {
            return $this->app->make('Litecms\Catporfolio\Catporfolio');
        });

                // Bind Catporfolio to repository
        $this->app->bind(
            'Litecms\Catporfolio\Interfaces\CatporfolioRepositoryInterface',
            \Litecms\Catporfolio\Repositories\Eloquent\CatporfolioRepository::class
        );

        $this->app->register(\Litecms\Catporfolio\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Catporfolio\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.catporfolio'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/catporfolio.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/catporfolio')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/catporfolio')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
